%bcond_without autoconf

Summary:    Gives a fake root environment
Name:       fakeroot
Version:    1.29
Release:    7%{?dist}
License:    GPLv3+ and LGPLv2+ and (GPL+ or Artistic)
URL:        https://tracker.debian.org/pkg/fakeroot
Source0:    https://cdn-aws.deb.debian.org/debian/pool/main/f/fakeroot/%{name}_%{version}.orig.tar.gz
Patch0001:  debian_fix-shell-in-fakeroot.patch
Patch0002:  also-wrap-stat-library-call.patch
Patch3000:  fakeroot-inttypes.patch
Patch3001:  fakeroot-multilib.patch
Patch3002:  relax_tartest.patch
Patch3003:  0001-fakeroot-1.29-fix-loongarch64-build-error-problem.patch

BuildRequires: gcc, make, autoconf, automake, po4a, libtool
BuildRequires: /usr/bin/getopt
BuildRequires: libacl-devel, libcap-devel, sharutils
Requires: /usr/bin/getopt
Requires(post): /usr/sbin/alternatives
Requires(post): /usr/bin/readlink
Requires(preun): /usr/sbin/alternatives

%description
fakeroot runs a command in an environment wherein it appears to have
root privileges for file manipulation. fakeroot works by replacing the
file manipulation library functions (chmod(2), stat(2) etc.) by ones
that simulate the effect the real library functions would have had,
had the user really been root.



%prep
%autosetup -p1



%build
./bootstrap
(cd doc && po4a -k 0 --rm-backups --variable "srcdir=../doc/" po4a/po4a.cfg) || exit 1

mkdir obj-sysv
pushd obj-sysv
../configure \
  --prefix=/usr \
  --mandir=/usr/share/man \
  --libdir=%{_libdir}/libfakeroot \
  --disable-dependency-tracking \
  --disable-static \
  --with-ipc=sysv \
  --program-suffix=-sysv
%make_build
popd

mkdir obj-tcp
pushd obj-tcp
../configure \
  --prefix=/usr \
  --mandir=/usr/share/man \
  --libdir=%{_libdir}/libfakeroot \
  --disable-dependency-tracking \
  --disable-static \
  --with-ipc=tcp \
  --program-suffix=-tcp
%make_build
popd



%install
pushd obj-sysv
make install libdir=%{_libdir}/libfakeroot DESTDIR=%{buildroot}
mv %{buildroot}%{_libdir}/libfakeroot/libfakeroot-0.so %{buildroot}%{_libdir}/libfakeroot/libfakeroot-sysv.so
popd

pushd obj-tcp
make install libdir=%{_libdir}/libfakeroot DESTDIR=%{buildroot}
mv %{buildroot}%{_libdir}/libfakeroot/libfakeroot-0.so %{buildroot}%{_libdir}/libfakeroot/libfakeroot-tcp.so
popd

rm -f %{buildroot}%{_libdir}/libfakeroot/libfakeroot.so
rm -f %{buildroot}%{_libdir}/libfakeroot/libfakeroot.*la

%find_lang faked-sysv --without-mo --with-man
%find_lang fakeroot-sysv --without-mo --with-man
%find_lang faked-tcp --without-mo --with-man
%find_lang fakeroot-tcp --without-mo --with-man

cat faked-sysv.lang >> fakeroot.lang
cat fakeroot-sysv.lang >> fakeroot.lang
cat faked-tcp.lang >> fakeroot.lang
cat fakeroot-tcp.lang >> fakeroot.lang



%check
(cd obj-sysv && make check)
(cd obj-tcp && make check)

%post
link=$(readlink -e "/usr/bin/fakeroot")
if [ "$link" = "/usr/bin/fakeroot" ]; then
  rm -f /usr/bin/fakeroot
fi
link=$(readlink -e "%{_bindir}/faked")
if [ "$link" = "%{_bindir}/faked" ]; then
  rm -f "%{_bindir}/faked"
fi
link=$(readlink -e "%{_libdir}/libfakeroot/libfakeroot-0.so")
if [ "$link" = "%{_libdir}/libfakeroot/libfakeroot-0.so" ]; then
  rm -f "%{_libdir}/libfakeroot/libfakeroot-0.so"
fi

/usr/sbin/alternatives --install "%{_bindir}/fakeroot" fakeroot \
  "%{_bindir}/fakeroot-tcp" 50 \
  --slave %{_bindir}/faked faked %{_bindir}/faked-tcp \
  --slave %{_libdir}/libfakeroot/libfakeroot-0.so libfakeroot.so %{_libdir}/libfakeroot/libfakeroot-tcp.so \

/usr/sbin/alternatives --install "%{_bindir}/fakeroot" fakeroot \
  "%{_bindir}/fakeroot-sysv" 40 \
  --slave %{_bindir}/faked faked %{_bindir}/faked-sysv \
  --slave %{_libdir}/libfakeroot/libfakeroot-0.so libfakeroot.so %{_libdir}/libfakeroot/libfakeroot-sysv.so \

%preun
if [ $1 = 0 ]; then
  /usr/sbin/alternatives --remove fakeroot "%{_bindir}/fakeroot-tcp"
  /usr/sbin/alternatives --remove fakeroot "%{_bindir}/fakeroot-sysv"
fi



%files -f %{name}.lang
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS BUGS DEBUG doc/README.saving
%{_bindir}/faked-*
%ghost %{_bindir}/faked
%{_bindir}/fakeroot-*
%ghost %{_bindir}/fakeroot
%dir %{_libdir}/libfakeroot
%{_libdir}/libfakeroot/libfakeroot-sysv.so
%{_libdir}/libfakeroot/libfakeroot-tcp.so
%ghost %{_libdir}/libfakeroot/libfakeroot-0.so
%{_mandir}/man1/*



%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29-6
- Rebuilt for loongarch release

* Fri May 31 2024 Pengda Dou <doupengda@loongson.cn> - 1.29-5
- [Type] bugfix
- [DESC] fix loongarch64 build error problem

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.29-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Jul 26 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.29-1
- Initial build.
